==> google_applovin_unity_ads-1.1.6.tar.gz: android/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads/CustomAdDialog.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads

import android.app.Dialog
import android.content.Context
import android.content.DialogInterface
import android.content.Intent
import android.graphics.drawable.ColorDrawable
import android.graphics.drawable.Drawable
import android.net.Uri
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.WindowManager
import com.bumptech.glide.load.DataSource
import com.bumptech.glide.load.engine.GlideException
import com.btcpiyush.ads.google_applovin_unity_ads.api.CustomAdsSetting
import com.btcpiyush.ads.google_applovin_unity_ads.databinding.CustomInterstitialAdsBinding
import com.btcpiyush.ads.google_applovin_unity_ads.image_loader.ImageLoadGlide
import com.btcpiyush.ads.google_applovin_unity_ads.image_loader.ImageLoadGlide.ImageLoad
import java.util.*

data class CustomAdDialog(
    val cntxt: Context,
    val setting: CustomAdsSetting,
    val listerner: DialogInterface
) : Dialog(cntxt, android.R.style.Theme_Black_NoTitleBar_Fullscreen), ImageLoad {
    private var dialogbinding: CustomInterstitialAdsBinding? = null

    interface DialogInterface {
        fun onLoaded()
        fun onDismiss()
        fun onFailed()
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        dialogbinding = CustomInterstitialAdsBinding.inflate(LayoutInflater.from(cntxt))
        dialogbinding?.let {
            setContentView(it.root)
            it.btnClose.setOnClickListener {
                dismiss()
                listerner.onDismiss()
                if (setting.closeButtonToDirectWeb == true) {
                    openPage()
                }
            }
            it.ivInterstitialImage.visibility = View.VISIBLE

            //scroll_desc = (ScrollView) findViewById(R.id.scroll_desc);

            //Toast.makeText(this,new Random().nextInt(Custom_Ads_Model.ads_List.size()) +" : custom Ads : "+ Custom_Ads_Model.ads_List.size(),Toast.LENGTH_SHORT).show();
            var random_index = Random().nextInt(setting.qurakaIntraImage.size)

            if (random_index >= setting.qurakaIntraImage.size) {
                random_index = setting.qurakaIntraImage.size - 1
            }

            ImageLoadGlide().imageLoad(
                setting.qurakaIntraImage[random_index],
                it.ivInterstitialImage,
                cntxt,
                this,
                it.progressbar
            )

            it.ivInterstitialImage.setOnClickListener(View.OnClickListener {
                openPage()
            })

        }
        setCanceledOnTouchOutside(false)
        val layoutParams = WindowManager.LayoutParams()
        layoutParams.copyFrom(window?.attributes)
        layoutParams.width = WindowManager.LayoutParams.MATCH_PARENT
        layoutParams.height = WindowManager.LayoutParams.MATCH_PARENT
        window?.attributes = layoutParams
        window?.setBackgroundDrawable(ColorDrawable(android.graphics.Color.TRANSPARENT))
    }

    private fun openPage() {
        setting.qurekaLink?.let {
            try {
                val browserIntent = Intent(Intent.ACTION_VIEW, Uri.parse(it))
                browserIntent.setPackage("com.android.chrome")
                context.startActivity(browserIntent)
            } catch (e: Exception) {
                try {
                    val browserIntent =
                        Intent(Intent.ACTION_VIEW, Uri.parse(it))
                    context.startActivity(browserIntent)
                } catch (e: Exception) {
                }
            }
        }
    }


    override fun onLoadFailed(
        e: GlideException?,
        model: Any?,
        target: com.bumptech.glide.request.target.Target<Drawable?>?,
        isFirstResource: Boolean
    ) {
        listerner.onFailed()
    }

    override fun onSuccess(
        resource: Drawable?,
        model: Any?,
        target: com.bumptech.glide.request.target.Target<Drawable?>?,
        dataSource: DataSource?,
        isFirstResource: Boolean
    ) {
        listerner.onLoaded()
    }
}

==> google_applovin_unity_ads-1.1.7.tar.gz: android/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads/CustomAdDialog.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads

import android.app.Dialog
import android.content.Context
import android.content.DialogInterface
import android.content.Intent
import android.graphics.drawable.ColorDrawable
import android.graphics.drawable.Drawable
import android.net.Uri
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.WindowManager
import com.bumptech.glide.load.DataSource
import com.bumptech.glide.load.engine.GlideException
import com.btcpiyush.ads.google_applovin_unity_ads.api.CustomAdsSetting
import com.btcpiyush.ads.google_applovin_unity_ads.databinding.CustomInterstitialAdsBinding
import com.btcpiyush.ads.google_applovin_unity_ads.image_loader.ImageLoadGlide
import com.btcpiyush.ads.google_applovin_unity_ads.image_loader.ImageLoadGlide.ImageLoad
import java.util.*

data class CustomAdDialog(
    val cntxt: Context,
    val setting: CustomAdsSetting,
    val listerner: DialogInterface
) : Dialog(cntxt, android.R.style.Theme_Black_NoTitleBar_Fullscreen), ImageLoad {
    private var dialogbinding: CustomInterstitialAdsBinding? = null

    interface DialogInterface {
        fun onLoaded()
        fun onDismiss()
        fun onFailed()
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        dialogbinding = CustomInterstitialAdsBinding.inflate(LayoutInflater.from(cntxt))
        dialogbinding?.let {
            setContentView(it.root)
            it.btnClose.setOnClickListener {
                dismiss()
                listerner.onDismiss()
                if (setting.closeButtonToDirectWeb == true) {
                    openPage()
                }
            }
            it.ivInterstitialImage.visibility = View.VISIBLE

            var random_index = Random().nextInt(setting.qurakaIntraImage.size)

            if (random_index >= setting.qurakaIntraImage.size) {
                random_index = setting.qurakaIntraImage.size - 1
            }

            ImageLoadGlide().imageLoad(
                setting.qurakaIntraImage[random_index],
                it.ivInterstitialImage,
                cntxt,
                this,
                it.progressbar
            )

            it.ivInterstitialImage.setOnClickListener {
                openPage()
            }

        }
        setCanceledOnTouchOutside(false)
        val layoutParams = WindowManager.LayoutParams()
        layoutParams.copyFrom(window?.attributes)
        layoutParams.width = WindowManager.LayoutParams.MATCH_PARENT
        layoutParams.height = WindowManager.LayoutParams.MATCH_PARENT
        window?.attributes = layoutParams
        window?.setBackgroundDrawable(ColorDrawable(android.graphics.Color.TRANSPARENT))
    }

    private fun openPage() {
        setting.qurekaLink?.let {
            try {
                val browserIntent = Intent(Intent.ACTION_VIEW, Uri.parse(it))
                browserIntent.setPackage("com.android.chrome")
                context.startActivity(browserIntent)
            } catch (e: Exception) {
                try {
                    val browserIntent =
                        Intent(Intent.ACTION_VIEW, Uri.parse(it))
                    context.startActivity(browserIntent)
                } catch (e: Exception) {
                }
            }
        }
    }


    override fun onLoadFailed(
        e: GlideException?,
        model: Any?,
        target: com.bumptech.glide.request.target.Target<Drawable?>?,
        isFirstResource: Boolean
    ) {
        listerner.onFailed()
    }

    override fun onSuccess(
        resource: Drawable?,
        model: Any?,
        target: com.bumptech.glide.request.target.Target<Drawable?>?,
        dataSource: DataSource?,
        isFirstResource: Boolean
    ) {
        listerner.onLoaded()
    }
}
